@@ -4,14 +4,13 @@ from tsdoc0.python.utils import repr_parent
 from typing import Final
 from typing import Iterable
 from typing import Optional
-from typing import Tuple
 
 import attr
 
 
 # This converter wrapper-function is used because of a bug with the mypy-attrs plugin.
 # https://github.com/python/mypy/issues/8389
-def _tuple(iterable: Iterable[str]) -> Tuple[str, ...]:
+def _tuple(iterable: Iterable[str]) -> tuple[str, ...]:
     return tuple(iterable)
 
 
@@ -19,7 +18,7 @@ def _tuple(iterable: Iterable[str]) -> Tuple[str, ...]:
 class Keywords(Segment):
     parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
-    terms: Final[Tuple[str, ...]] = attr.ib(converter=_tuple)
+    terms: Final[tuple[str, ...]] = attr.ib(converter=_tuple)
 
     @property
     def callout(self) -> str:
